summaryrefslogtreecommitdiffstats
path: root/src/H5VLprivate.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
commit1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96 (patch)
treec1f53073ff700c02397231fec2b2075a7391d87f /src/H5VLprivate.h
parentdeb75622ca18958ea729c7184c4bc5ea0e029280 (diff)
downloadhdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.zip
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.gz
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.bz2
Switch driver | plugin => connector.
Diffstat (limited to 'src/H5VLprivate.h')
-rw-r--r--src/H5VLprivate.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/H5VLprivate.h b/src/H5VLprivate.h
index ee6b7d4..83e9600 100644
--- a/src/H5VLprivate.h
+++ b/src/H5VLprivate.h
@@ -26,24 +26,24 @@
/* Library Private Typedefs */
/****************************/
/* Internal struct to track VOL plugin information for objects */
typedef struct H5VL_t {
- const H5VL_class_t *cls; /* Pointer to plugin class struct */
+ const H5VL_class_t *cls; /* Pointer to connector class struct */
int64_t nrefs; /* Number of references by objects using this struct */
- hid_t id; /* Identifier for the VOL plugin */
+ hid_t id; /* Identifier for the VOL connector */
} H5VL_t;
/* Internal vol object structure returned to the API */
typedef struct H5VL_object_t {
- void *data; /* Pointer to plugin-managed data for this object */
- H5VL_t *plugin; /* Pointer to VOL plugin struct */
+ void *data; /* Pointer to connector-managed data for this object */
+ H5VL_t *connector; /* Pointer to VOL connector struct */
} H5VL_object_t;
-/* Internal structure to hold the plugin ID & info for FAPLs */
-typedef struct H5VL_plugin_prop_t {
- hid_t plugin_id; /* VOL plugin's ID */
- const void *plugin_info; /* VOL plugin info, for open callbacks */
-} H5VL_plugin_prop_t;
+/* Internal structure to hold the connector ID & info for FAPLs */
+typedef struct H5VL_connector_prop_t {
+ hid_t connector_id; /* VOL connector's ID */
+ const void *connector_info; /* VOL connector info, for open callbacks */
+} H5VL_connector_prop_t;
/*****************************/
/* Library Private Variables */
@@ -55,16 +55,16 @@ typedef struct H5VL_plugin_prop_t {
/* Utility functions */
H5_DLL herr_t H5VL_init(void);
-H5_DLL int H5VL_cmp_plugin_cls(const H5VL_class_t *cls1, const H5VL_class_t *cls);
-H5_DLL int H5VL_copy_plugin_info(const H5VL_class_t *plugin, void **dst_info,
+H5_DLL int H5VL_cmp_connector_cls(const H5VL_class_t *cls1, const H5VL_class_t *cls);
+H5_DLL int H5VL_copy_connector_info(const H5VL_class_t *connector, void **dst_info,
const void *src_info);
-H5_DLL int H5VL_cmp_plugin_info(const H5VL_class_t *plugin, const void *info1,
+H5_DLL int H5VL_cmp_connector_info(const H5VL_class_t *connector, const void *info1,
const void *info2);
-H5_DLL herr_t H5VL_free_plugin_info(const H5VL_class_t *plugin, void *info);
+H5_DLL herr_t H5VL_free_connector_info(const H5VL_class_t *connector, void *info);
-/* Functions that deal with VOL plugins */
-H5_DLL hid_t H5VL_register_plugin(const void *cls, hbool_t app_ref, hid_t vipl_id);
-H5_DLL ssize_t H5VL_get_plugin_name(hid_t id, char *name/*out*/, size_t size);
+/* Functions that deal with VOL connectors */
+H5_DLL hid_t H5VL_register_connector(const void *cls, hbool_t app_ref, hid_t vipl_id);
+H5_DLL ssize_t H5VL_get_connector_name(hid_t id, char *name/*out*/, size_t size);
/* NOTE: The object and ID functions below deal in VOL objects (i.e.;
* H5VL_object_t). Similar non-VOL calls exist in H5Iprivate.h. Use
@@ -84,22 +84,22 @@ H5_DLL H5VL_object_t *H5VL_vol_object(hid_t id);
H5_DLL herr_t H5VL_free_object(H5VL_object_t *obj);
/* Functions that wrap / unwrap VOL objects */
-H5_DLL herr_t H5VL_get_wrap_ctx(const H5VL_class_t *plugin, void *obj,
+H5_DLL herr_t H5VL_get_wrap_ctx(const H5VL_class_t *connector, void *obj,
void **wrap_ctx);
-H5_DLL herr_t H5VL_free_wrap_ctx(const H5VL_class_t *plugin, void *wrap_ctx);
-H5_DLL herr_t H5VL_set_vol_wrapper(void *obj, const H5VL_t *vol_plugin);
+H5_DLL herr_t H5VL_free_wrap_ctx(const H5VL_class_t *connector, void *wrap_ctx);
+H5_DLL herr_t H5VL_set_vol_wrapper(void *obj, const H5VL_t *vol_connector);
H5_DLL herr_t H5VL_reset_vol_wrapper(void);
-H5_DLL void * H5VL_wrap_object(const H5VL_class_t *plugin, void *wrap_ctx,
+H5_DLL void * H5VL_wrap_object(const H5VL_class_t *connector, void *wrap_ctx,
void *obj);
/* ID registration functions */
-H5_DLL hid_t H5VL_register(H5I_type_t type, void *object, H5VL_t *vol_plugin, hbool_t app_ref);
+H5_DLL hid_t H5VL_register(H5I_type_t type, void *object, H5VL_t *vol_connector, hbool_t app_ref);
H5_DLL hid_t H5VL_wrap_register(H5I_type_t type, void *obj, hbool_t app_ref);
-H5_DLL hid_t H5VL_register_using_vol_id(H5I_type_t type, void *obj, hid_t driver_id, hbool_t app_ref);
-H5_DLL herr_t H5VL_register_using_existing_id(H5I_type_t type, void *object, H5VL_t *vol_driver, hbool_t app_ref, hid_t existing_id);
+H5_DLL hid_t H5VL_register_using_vol_id(H5I_type_t type, void *obj, hid_t connector_id, hbool_t app_ref);
+H5_DLL herr_t H5VL_register_using_existing_id(H5I_type_t type, void *object, H5VL_t *vol_connector, hbool_t app_ref, hid_t existing_id);
/******************************
* VOL plugin callback wrappers
*****************************/
/* Attribute functions */
@@ -26,24 +26,24 @@
/* Library Private Typedefs */
/****************************/
-/* Internal struct to track VOL plugin information for objects */
+/* Internal struct to track VOL connector information for objects */
typedef struct H5VL_t {
@@ -84,22 +84,22 @@ H5_DLL H5VL_object_t *H5VL_vol_object(hid_t id);
/******************************
- * VOL plugin callback wrappers
+ * VOL connector callback wrappers
*****************************/
/* Attribute functions */